@@ -28,25 +28,14 @@
 # SOFTWARE.
 # ==============================================================================
 
-import socket
 from typing import Optional
 
-from .net import BaseChannel
+from startrek import BaseChannel
 
 
 class StreamChannel(BaseChannel):
     """ Stream Channel """
 
-    # Override
-    def _setup_socket(self) -> socket.socket:
-        sock = self._sock
-        if sock is None:
-            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEPORT, self._reuse)
-            sock.setblocking(self._blocking)
-            self._sock = sock
-        return sock
-
     # Override
     def receive(self, max_len: int) -> (Optional[bytes], Optional[tuple]):
         data = self.read(max_len=max_len)
@@ -59,4 +48,6 @@ class StreamChannel(BaseChannel):
     def send(self, data: bytes, target: tuple) -> int:
         # TCP channel will be always connected
         # so the target address must be the remote address
+        remote = self.remote_address
+        assert target is None or target == remote, 'target address error: %s, %s' % (target, remote)
         return self.write(data=data)
